@@ -1,6 +1,6 @@
 package Gerrit::REST;
 {
-  $Gerrit::REST::VERSION = '0.010';
+  $Gerrit::REST::VERSION = '0.011';
 }
 # ABSTRACT: Thin wrapper around Gerrit's REST API
 
@@ -90,7 +90,7 @@ sub _error {
     } else {
         $msg .= "<unconvertable Content-Type: '$type'>";
     };
-    $msg =~ s/\n*$//s;       # strip trailing newlines
+    $msg =~ s/\n*$/\n/s;       # end message with a single newline
     return $msg;
 }
 
@@ -111,7 +111,7 @@ sub _content {
         if (substr($content, 0, 4) eq ")]}'") {
             return $self->{json}->decode(substr($content, 5));
         } else {
-            croak $self->_error("Missing \")]}'\" prefix for JSON content:\n$content");
+            croak $self->_error("Missing \")]}'\" prefix for JSON content:\n\n$content");
         }
     } elsif ($type =~ m:^text/plain:i) {
         return $content;
@@ -124,7 +124,7 @@ sub GET {
     my ($self, $resource) = @_;
 
     eval { $self->{rest}->GET("/a$resource") }
-        or croak $self->_error($@);
+        or croak $self->_error("Error in GET(/a$resource): $@");
 
     return $self->_content();
 }
@@ -133,7 +133,7 @@ sub DELETE {
     my ($self, $resource) = @_;
 
     eval { $self->{rest}->DELETE("/a$resource") }
-        or croak $self->_error($@);
+        or croak $self->_error("Error in DELETE(/a$resource): $@");
 
     return $self->_content();
 }
@@ -146,7 +146,7 @@ sub PUT {
         $self->{json}->encode($value),
         {'Content-Type' => 'application/json;charset=UTF-8'},
     ) }
-        or croak $self->_error($@);
+        or croak $self->_error("Error in PUT(/a$resource, ...): $@");
 
     return $self->_content();
 }
@@ -159,7 +159,7 @@ sub POST {
         $self->{json}->encode($value),
         {'Content-Type' => 'application/json;charset=UTF-8'},
     ) }
-        or croak $self->_error($@);
+        or croak $self->_error("Error in POST(/a$resource, ...): $@");
 
     return $self->_content();
 }
@@ -178,7 +178,7 @@ Gerrit::REST - Thin wrapper around Gerrit's REST API
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -331,6 +331,10 @@ API based on SSH.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/gnustavo/Gerrit-REST>
+
 =head1 AUTHOR
 
 Gustavo L. de M. Chaves <gnustavo@cpan.org>
